<?php
//echo $_SESSION['nume_folder'];
if($_SESSION['logat'] == 'Da'){

// start pagina start
if($_GET['pag'] == 'start'){
		echo'<a href="index.php?pag=firma"><p id="buton_start">Adauga/Modifica</p></a>';
		echo'<a href="index.php?pag=cauta"><p id="buton_start">Cauta documente</p></a>';
		echo '<a href="deconectare.php"><p id="butonnext">Iesire</p></a>';
		echo '<a href="index.php?pag=start"><p id="butonnext">Home</p></a>';
}else{
if($_GET['pag'] != 'cauta'){
	echo '<a href="index.php?pag=firma"><p id="butonprogresverde">Firme</p></a>';
	echo '<a href="index.php?pag=user"><p id="butonprogresverde">Utilizatori</p></a>';
	echo '<a href="index.php?pag=doc"><p id="butonprogresverde">Documente</p></a>';
	echo '<a href="index.php?pag=start"><p id="butonnext">Home</p></a>';
echo'</div>';
	}
if($_GET['pag'] == 'cauta'){
	echo'<a href="index.php?pag=cauta"><p id="buton_start">Cauta documente</p></a>';
	echo '<a href="index.php?pag=start"><p id="butonnext">Home</p></a>';
echo'</div>';
// end bara progres sus
	}
}
}else{
	echo'<p id="butonmarealbastru">
		<marquee behavior="alternate" direction="left">
			'.$text1.' - '.$text3.'
		</marquee></p>';
}	
?>