<?php
$timp_expirare_cod_validare = 500; // 100 = 1 minut
$timp_expirare_blocare_user = 1000000; // 100 = 1 minut
$form_autentificare = '
<br /><br /><br /><br />
<TABLE width="60%" align="center">
	<form action="" method="post">
		<TR>
			<TD height="100px" align="center" colspan="2">Pentru acces in aplicatie este nevoie de autentificare.<br />Va rugam introduceti datele necesare in campurile de mai jos</TD>
		</TR>
		<TR>
			<TD align="right">Nume utilizator :</TD>
			<TD align="left"><input id="campdreapta" type="text" name="nume_utilizator"></TD>
		</TR>
		<TR>
			<TD align="right">Parola :</TD>
			<TD align="left"><input id="campdreapta" type="password" name="parola"></TD>
		</TR>
		<TR>
			<TD align="right">6+4=</TD>			
			<TD align="left"><input id="codsecuritate" type="text" name="cod_securitate" value=""></TD>
		</TR>
		<TR>
			<TD align="center" colspan="2">Toate campurile sunt obligatorii</TD>
		</TR>
		<TR>
			<TD align="center" colspan="2">
				<input type="hidden" name="crt" value="1">
				<input id="butonsubmit" type="submit" name="autentificare" value="Autentificare">
			</TD>
		</TR>
	</form>
</TABLE>';
if($_POST['validare']) {
	if($_SESSION['incercari'] > '5' and $ymdhis < $_SESSION['data_deblocare'] and $_SESSION['ip'] == $_SERVER['REMOTE_ADDR']){
		echo "<script>alert('Autentificare ESUATA. User blocat pana la data ".$_SESSION['data_deblocare']."')</script>";
				echo "<script>location.replace('index.php')</script>";
	}else{
	if($_POST['cod_validare'] == $_SESSION["cod_validare"]){
		$sql = mysqli_query($conn, "UPDATE `utilizatori` SET `data_autentificare`='".$ymdhis."', `incercari`='0', `ip`='".$_SERVER['REMOTE_ADDR']."' WHERE `id`='".$_SESSION['id_user']."'")or die(mysql_error());	
	$verif = "SELECT * FROM `utilizatori` where id ='".$_SESSION['id_user']."'";
		$result = $conn->query($verif);	
		while($row = $result->fetch_assoc()) {
		
				$_SESSION['logat'] = 'Da';
				$_SESSION['nume_utilizator'] = $row["nume"].' '.$row["prenume"];
				$_SESSION['rol'] = $row["rol"];
				
		echo "<script>alert('Autentificare realizata cu SUCCES. Bine ai venit ".$_SESSION['nume_utilizator']."')</script>";
		echo "<script>location.replace('index.php?pag=start')</script>";
	   // echo '<META HTTP-EQUIV=Refresh CONTENT="0; URL=index.php">';
		
}
	}else{
		$sql = mysqli_query($conn, "UPDATE `utilizatori` SET `incercari`='".($_SESSION['incercari']+1)."' WHERE `id`='".$_SESSION['id_user']."'")or die(mysql_error());
			echo "<script>alert('Autentificare ESUATA. Mai aveti ".(5-$_SESSION['incercari'])." incercari dupa care se va interzice accesul pentru 24 ore.')</script>";
			echo "<script>location.replace('index.php')</script>";
		}
	}
	
}
// start autentificare
if($_POST['autentificare']) {

$nume_utilizator = md5($_POST['nume_utilizator']);
$parola = md5(trim($_POST['parola']));
$cod_securitate = md5(trim($_POST['cod_securitate']));
$cod_securitate_md5 = 'd3d9446802a44259755d38e6d163e820';

if($_SESSION['cod_validare'] != ''){
		$_SESSION['cod_validare'] = $_SESSION['cod_validare'];
	}else{
		$_SESSION['cod_validare'] = substr(rand(),0,8);
	}
$sql = mysqli_query($conn, "UPDATE `utilizatori` SET `data_autentificare`='".$ymdhis."', `cod_validare`='".$_SESSION['cod_validare']."' WHERE `id`='".$_SESSION['id_user']."'")or die(mysql_error());
//echo $ymdhis;
$useri = "SELECT * FROM `utilizatori` where user ='".$nume_utilizator."'";
	$result = $conn->query($useri);
if ($result->num_rows > 0) {
    while($row = $result->fetch_assoc()) {
		$_SESSION['id_user'] = $row["id"];
		$_SESSION['ip'] = $row["ip"];
		$_SESSION['incercari'] = $row["incercari"];
		$_SESSION['data_autentificare'] = $row["data_autentificare"];
		$_SESSION['data_deblocare'] = ($row["data_autentificare"]+$timp_expirare_blocare_user); 

		if(($nume_utilizator != $row["user"]) or ($parola != $row["parola"] ) or ($cod_securitate != $cod_securitate_md5 )){	

	echo '<div style="text-align: center; color: red;">
				Date incorecte.<br />
				Va rugam completati campurile cu atentie.<br />
				Toate campurile sunt obligatorii
			</div>';
			echo $form_autentificare;
		}else{
if($row["status"] != 'Activ'){
		echo '<div style="text-align: center; color: red;">
			<b>ACCES NEAUTORIZAT</b><br />
			Utilizator INACTIV.<br />
			Accesul de la IP-ul <b>'.$_SERVER['REMOTE_ADDR'].'</b> a fost inregistrat si blocat<br />
			Va rugam contactati administratorul.<br />
		</div>';
$sql = mysqli_query($conn, "UPDATE `utilizatori` SET `ip`='".$_SERVER['REMOTE_ADDR']." Blocat' WHERE `id`='".$_SESSION['id_user']."'")or die(mysql_error());

	echo '<META HTTP-EQUIV=Refresh CONTENT="20; URL=https://bit.ly/2UHWbWr">';
	
	}else{
	$to = $row["email"];
	$subject = "Cod securitate Aplicatie Arhiva Electronica";
	$headers = "MIME-Version: 1.0"."\r\n";
	$headers .= "Content-type: text/html; charset=iso-8859-1"."\r\n";
	$headers .= "From: no_reply@e-arhiva.eu<no_reply@e-arhiva.eu>"."\r\n";

	$text1 = 'Cod de siguranta: ';
	$text3 = ', expira dupa 300 secunde.';
	$content = $text1.''.$_SESSION['cod_validare'].''.$text3;
	//echo $content;
	mail($to , $subject, $content, $headers );


	
$lungime_email = strpos($row["email"], "@");
		
echo '
<br /><br /><br /><br />
<TABLE width="60%" align="center">
	<form action="" method="post">
		<TR>
			<TD height="100px" align="center" colspan="2">Introduceti Codul de Siguranta ce a fost transmis pe adresa de email: '.substr($row["email"],0,3).'********'.substr($row["email"],($lungime_email-3), $lungime_email).' si este valabil doar 5 minute.</TD>
		</TR>
		<TR>
			<TD align="right">Cod de siguranta :</TD>
			<TD align="left"><input id="campdreapta" type="password" name="cod_validare"></TD>
		</TR>
		<TR>
			<TD align="center" colspan="2"><br /></TD>
		</TR>
		<TR>
			<TD align="center" colspan="2">
				<input id="butonsubmit" type="submit" name="validare" value="Validare">
			</TD>
		</TR>
	</form>
</TABLE>';		
		}
	}
}
		}else{
		echo "Acest utilizator nu exista";
	}
}
//$conn->close();
//$_SESSION['logat'] = 'Da';
if($_POST['crt'] == ''){
	echo $form_autentificare;
}
?>